## 简介

在AutoLink中，我们如何用Python写我们自己的测试库呢？


## 项目结构

如下图所示，在AutoLink中写Python

![Python项目示例](./img/python_project.png)

## 步骤

1. 新增一个Python文件，写上你的Python代码，如图

![python源码](./img/python_code.png)

2. 通过相对路径导入上述库，如图

![python关键字](./img/python_keyword.png)